@@ -7,6 +7,12 @@
 
 #include "audiorecorder.h"
 
+AudioRecorder* AudioRecorder::instance()
+{
+    static AudioRecorder *s_audioRecorder = new AudioRecorder(qApp);
+    return s_audioRecorder;
+}
+
 AudioRecorder::AudioRecorder(QObject *parent) : QAudioRecorder(parent)
 {
     m_audioProbe = new AudioProber(parent, this);
@@ -18,18 +24,39 @@ AudioRecorder::AudioRecorder(QObject *parent) : QAudioRecorder(parent)
     connect(this, &QAudioRecorder::stateChanged, this, &AudioRecorder::handleStateChange);
 }
 
+AudioProber* AudioRecorder::prober()
+{
+    return m_audioProbe;
+}
+    
+QString AudioRecorder::audioCodec() 
+{
+    return m_encoderSettings.codec();
+}
+
 void AudioRecorder::setAudioCodec(const QString &codec)
 {
     m_encoderSettings.setCodec(codec);
     setAudioSettings(m_encoderSettings);
-    emit audioCodecChanged();
+    Q_EMIT audioCodecChanged();
+}
+
+int AudioRecorder::audioQuality() 
+{
+    return m_encoderSettings.quality();
 }
 
 void AudioRecorder::setAudioQuality(int quality)
 {
     m_encoderSettings.setQuality(QMultimedia::EncodingQuality(quality));
     setAudioSettings(m_encoderSettings);
-    emit audioQualityChanged();
+    Q_EMIT audioQualityChanged();
+}
+
+void AudioRecorder::reset()
+{
+    resetRequest = true;
+    stop();
 }
 
 void AudioRecorder::handleStateChange(QAudioRecorder::State state)
@@ -40,7 +67,7 @@ void AudioRecorder::handleStateChange(QAudioRecorder::State state)
             resetRequest = false;
             QFile(actualLocation().toString()).remove();
             qDebug() << "Discarded recording " << actualLocation().toString();
-            recordingName = "";
+            recordingName = QString();
             
         } else {
             // rename file to desired file name
@@ -60,9 +87,9 @@ void AudioRecorder::renameCurrentRecording()
     if (!recordingName.isEmpty()) {
         
         // determine new file name
-        QStringList spl = actualLocation().fileName().split(".");
-        QString suffix = spl.size() > 0 ? "." + spl[spl.size()-1] : "";
-        QString path = QStandardPaths::writableLocation(QStandardPaths::MusicLocation) + "/" + recordingName;
+        QStringList spl = actualLocation().fileName().split(QStringLiteral("."));
+        QString suffix = spl.size() > 0 ? QStringLiteral(".") + spl[spl.size()-1] : QString();
+        QString path = QStandardPaths::writableLocation(QStandardPaths::MusicLocation) + QStringLiteral("/") + recordingName;
         QString updatedPath = path + suffix;
         
         // ignore if the file destination is the same as the one currently being written to
@@ -71,7 +98,7 @@ void AudioRecorder::renameCurrentRecording()
             int cur = 1;
             QFileInfo check(updatedPath);
             while (check.exists()) {
-                updatedPath = QString("%1_%2%3").arg(path, QString::number(cur), suffix);
+                updatedPath = QStringLiteral("%1_%2%3").arg(path, QString::number(cur), suffix);
                 check = QFileInfo(updatedPath);
                 cur++;
             }
@@ -80,17 +107,21 @@ void AudioRecorder::renameCurrentRecording()
         }
      
         savedPath = updatedPath;
-        recordingName = "";
+        recordingName = QString();
     } else {
         savedPath = actualLocation().path();
     }
 }
 
+void AudioRecorder::setRecordingName(const QString &rName) {
+    recordingName = rName;
+}
+
 void AudioRecorder::saveRecording() 
 {
     // get file name from path
-    QStringList spl = savedPath.split("/");
-    QString fileName = spl.at(spl.size()-1).split(".")[0];
+    QStringList spl = savedPath.split(QStringLiteral("/"));
+    QString fileName = spl.at(spl.size()-1).split(QStringLiteral("."))[0];
     
     RecordingModel::instance()->insertRecording(savedPath, fileName, QDateTime::currentDateTime(), cachedDuration / 1000);
 }
