@@ -1,5 +1,6 @@
 /*
  * SPDX-FileCopyrightText: 2020 Jonah Brüchert <jbb@kaidan.im>
+ * SPDX-FileCopyrightText: 2022 Devin Lin <devin@kde.org>
  *
  * SPDX-License-Identifier: GPL-3.0-or-later
  */
@@ -17,6 +18,7 @@
 #include <KLocalizedContext>
 #include <KLocalizedString>
 
+#include "about.h"
 #include "recordingmodel.h"
 #include "utils.h"
 #include "audioplayer.h"
@@ -29,6 +31,15 @@ Q_DECL_EXPORT int main(int argc, char *argv[])
 {
     QGuiApplication::setAttribute(Qt::AA_EnableHighDpiScaling);
     
+    // set default style
+    if (qEnvironmentVariableIsEmpty("QT_QUICK_CONTROLS_STYLE")) {
+        QQuickStyle::setStyle(QStringLiteral("org.kde.desktop"));
+    }
+    // if using org.kde.desktop, ensure we use kde style if possible
+    if (qEnvironmentVariableIsEmpty("QT_QPA_PLATFORMTHEME")) {
+        qputenv("QT_QPA_PLATFORMTHEME", "kde");
+    }
+
     QApplication app(argc, argv);
     
     if (qEnvironmentVariableIsEmpty("QT_QUICK_CONTROLS_STYLE")) {
@@ -42,7 +53,7 @@ Q_DECL_EXPORT int main(int argc, char *argv[])
                          QStringLiteral(KRECORDER_VERSION_STRING),
                          QStringLiteral("Audio recorder"),
                          KAboutLicense::GPL,
-                         i18n("© 2020-2021 KDE Community"));
+                         i18n("© 2020-2022 KDE Community"));
     aboutData.setBugAddress("https://invent.kde.org/plasma-mobile/krecorder/-/issues");
     aboutData.addAuthor(i18n("Devin Lin"), QString(), QStringLiteral("devin@kde.org"));
     aboutData.addAuthor(i18n("Jonah Brüchert"), QString(), QStringLiteral("jbb@kaidan.im"));
@@ -78,10 +89,11 @@ Q_DECL_EXPORT int main(int argc, char *argv[])
     qmlRegisterSingletonType<SettingsModel>("KRecorder", 1, 0, "SettingsModel", [] (QQmlEngine *, QJSEngine *) -> QObject* {
        return SettingsModel::instance();
     });
-    
+
+    qmlRegisterSingletonInstance("KRecorder", 1, 0, "AboutType", &AboutType::instance());
     
     QQmlApplicationEngine engine;
-    engine.rootContext()->setContextProperty(QStringLiteral("KRecorderAboutData"), QVariant::fromValue(aboutData));
+
     engine.rootContext()->setContextObject(new KLocalizedContext(&engine));
     engine.load(QUrl(QStringLiteral("qrc:///main.qml")));
 
